@@ -74,10 +74,6 @@ R6_mdb_cursor <- R6::R6Class(
       txn$.deps$add(self)
     },
 
-    finalize = function() {
-      self$.invalidate()
-    },
-
     format = function() {
       format_thor(self)
     },
@@ -198,4 +194,9 @@ R6_mdb_cursor <- R6::R6Class(
       self$move_to(key)
       self$value(as_proxy, as_raw)
     }
+  ),
+  private = list(
+    finalize = function() {
+      self$.invalidate()
+    }
   ))
